"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var request = require("superagent");
var common_1 = require("../common");
function listDeployedRecipes(args) {
    common_1.authenticate(args, _listDeployedRecipes);
}
exports.listDeployedRecipes = listDeployedRecipes;
function _listDeployedRecipes(args, host, token) {
    var search = args["search"];
    var source = args["source"];
    var target = args["target"];
    var offset = args["offset"];
    var limit = args["limit"];
    var all = args["all"];
    var environment = args["environment"];
    if (all && environment) {
        common_1.printDetailedError("Conflicting arguments", null);
        process.exit(1);
    }
    environment = environment || common_1.getEnvId();
    if (!all && !environment) {
        common_1.printWarning("No environment specified. Listing all deployed recipes on all environments");
        all = true;
    }
    var reqURL = null;
    if (all) {
        reqURL = host + common_1.citizenApiPrefix + "/orgs/" + common_1.getOrgId() + "/deployed-recipes";
    }
    else {
        reqURL = host + common_1.citizenApiPrefix + "/orgs/" + common_1.getOrgId() + "/environments/" + environment + "/recipes";
    }
    var r = request.get(reqURL)
        .set("authToken", token);
    if (search) {
        r.query("search=" + search);
    }
    if (source) {
        r.query("source=" + source);
    }
    if (target) {
        r.query("target=" + target);
    }
    if (offset) {
        r.query("offset=" + offset);
    }
    if (limit) {
        r.query("limit=" + limit);
    }
    r.end(function (err, res) {
        if (err) {
            common_1.printDetailedError("Could not list deployed recipes " +
                (all ? "in all environments" : "in environment " + environment), err);
            process.exit(1);
        }
        else {
            var deployedRecipes = res.body;
            deployedRecipes.sort(function (a, b) {
                if (+a.projectId < +b.projectId) {
                    return -1;
                }
                if (+a.projectId > +b.projectId) {
                    return 1;
                }
                return 0;
            });
            if (deployedRecipes.length === 0) {
                console.log("No deployed recipes found " +
                    (all ? "in all environments" : "in environment " + environment) + ".");
            }
            else {
                for (var _i = 0, deployedRecipes_1 = deployedRecipes; _i < deployedRecipes_1.length; _i++) {
                    var deployedRecipe = deployedRecipes_1[_i];
                    var id = deployedRecipe.projectId;
                    var name_1 = deployedRecipe.name;
                    var authorName = deployedRecipe.author.name;
                    var authorOrgName = deployedRecipe.author.orgName;
                    console.log("[" + id + "] " + name_1 + " by " + authorName +
                        (authorOrgName ? " (" + authorOrgName + ")" : ""));
                }
            }
        }
    });
}
