"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var getmac = require("getmac");
var os = require("os");
var p = require("prompt-sync");
var request = require("superagent");
var common_1 = require("./common");
var prompt = p({ sigint: true });
function login(args) {
    var host = args["host"];
    var email = args["email"];
    var password = args["password"];
    if (!password) {
        try {
            password = prompt.hide("Password: ");
        }
        catch (err) {
            common_1.printDetailedError("Could not read password. This likely means that you are using Cygwin on Windows. " +
                "If so, please use Command Prompt instead", err);
            process.exit(1);
        }
    }
    _login(args, email, password, host);
}
exports.login = login;
function _login(args, email, password, host) {
    host = "https://" + host.toLowerCase().match(/^(?:[a-z]+:\/\/)?([^\/]+)(?:.*)?$/)[1];
    getmac.getMac(function (err, macAddress) {
        if (err) {
            common_1.printDetailedError("Could not get MAC address of device", err);
            process.exit(1);
        }
        else {
            var reqURL = host + common_1.harmonyApiPrefix + "/user/login";
            request.put(reqURL)
                .send({ email: email, password: password, deviceId: macAddress })
                .end(function (erro, res) {
                if (erro) {
                    if (erro.status === 404 || erro.status === 405) {
                        _loginCitizen(host, email, password, macAddress);
                    }
                    else if (erro.errorCode === "VALIDATE_TFA_LOGIN_EMAIL") {
                        common_1.doTFA(host, email, password, macAddress);
                    }
                    else {
                        common_1.printDetailedError("Authentication failed", erro);
                        process.exit(1);
                    }
                }
                else {
                    if (!res.body.status) {
                        if (res.body.errorCode === "VALIDATE_TFA_LOGIN_EMAIL") {
                            common_1.doTFA(host, email, password, macAddress, true);
                        }
                        else if (res.body && Object.keys(res.body).length === 0) {
                            _loginCitizen(host, email, password, macAddress);
                        }
                        else {
                            common_1.printDetailedError("Authentication failed", res.body);
                            process.exit(1);
                        }
                    }
                    else {
                        common_1.handleHarmonyLoginResponse(res, host, email, password);
                    }
                }
            });
        }
    });
}
function _loginCitizen(host, email, password, macAddress) {
    var reqURL = host + common_1.citizenApiPrefix + "/login";
    request.post(reqURL)
        .set({
        browser: "N/A",
        client: "jbcli",
        os: os.type(),
    })
        .type("form")
        .send({ email: email, password: password, deviceId: macAddress })
        .end(function (err, res) {
        if (err) {
            if (err.response.body.errorCode === "VALIDATE_TFA_LOGIN_EMAIL") {
                common_1.doTFA(host, email, password, macAddress);
            }
            else {
                common_1.printDetailedError("Authentication failed", err);
                process.exit(1);
            }
        }
        else {
            common_1.handleCitizenLoginResponse(res.body, host, email, password);
        }
    });
}
