"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var jsonfile = require("jsonfile");
var path = require("path");
var request = require("superagent");
var common_1 = require("../common");
var common_2 = require("../common");
function generateRecipe(args) {
    common_2.authenticate(args, _generateRecipe);
}
exports.generateRecipe = generateRecipe;
function _generateRecipe(args, host, token) {
    var jpk = args["jpk"];
    var genConfigure = !(args["recipeonly"] || false);
    var genRecipe = !(args["configonly"] || false);
    var basename = path.basename(jpk, ".jpk");
    var directory = path.dirname(jpk);
    var configureFile = common_1.normalizePath(path.join(directory, basename + "-configure.json"));
    var recipeFile = common_1.normalizePath(path.join(directory, basename + ".json"));
    var reqURL = host + common_1.citizenApiPrefix + "/generate/recipe";
    var r = request.put(reqURL)
        .set("authToken", token)
        .attach("jitterpack", jpk)
        .field("genConfigure", genConfigure.toString())
        .field("genRecipe", genRecipe.toString());
    r.type("multipart/form-data");
    r.end(function (err, res) {
        if (err) {
            common_1.printDetailedError("Generate failed", err);
            process.exit(1);
        }
        else {
            if (genConfigure && common_1.canWriteToPath(configureFile)) {
                jsonfile.writeFileSync(configureFile, res.body.configure, { spaces: 2 });
                console.log("Configure file saved to %s", configureFile);
            }
            if (genRecipe && common_1.canWriteToPath(recipeFile)) {
                jsonfile.writeFileSync(recipeFile, res.body.recipe, { spaces: 2 });
                console.log("Recipe saved to %s", recipeFile);
            }
        }
    });
}
