"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var jsonfile = require("jsonfile");
var path = require("path");
var request = require("superagent");
var common_1 = require("../common");
function getRecipe(args) {
    var savejpk = args["savejpk"];
    if (savejpk) {
        common_1.authenticate(args, _getRecipe, _getRecipeContent);
    }
    else {
        common_1.authenticate(args, _getRecipe);
    }
}
exports.getRecipe = getRecipe;
function _getRecipe(args, host, token, callAgain) {
    var id = args["id"];
    var saverecipe = args["saverecipe"];
    if (saverecipe) {
        saverecipe = common_1.normalizePath(saverecipe);
    }
    var clean = args["clean"];
    var reqURL = host + common_1.citizenApiPrefix + "/orgs/" + common_1.getOrgId() + "/recipes/" + id;
    request.get(reqURL)
        .set("authToken", token)
        .end(function (err, res) {
        if (err) {
            common_1.printDetailedError("Could not get recipe with ID " + id, err);
            process.exit(1);
        }
        else {
            var result = res.body.projectName;
            var recipe = res.body;
            if (clean) {
                recipe = _cleanRecipe(res.body);
            }
            if (saverecipe) {
                if (fs.existsSync(saverecipe) && fs.lstatSync(saverecipe).isDirectory()) {
                    saverecipe = path.join(saverecipe, result + ".json");
                }
                if (!common_1.canWriteToPath(saverecipe)) {
                    saverecipe = null;
                }
            }
            if (saverecipe) {
                jsonfile.writeFileSync(saverecipe, recipe, { spaces: 2 });
                console.log("Recipe saved to %s.", saverecipe);
            }
            else {
                console.log(JSON.stringify(recipe, undefined, 2));
            }
            if (callAgain) {
                callAgain(args, host, token, recipe.projectName || "jitterpak");
            }
        }
    });
}
function _cleanRecipe(recipe) {
    var keepThese = ["description", "name", "projectName", "steps", "projectVariables", "tags", "guid"];
    for (var k in recipe) {
        if (recipe.hasOwnProperty(k)) {
            if (keepThese.indexOf(k) < 0) {
                delete recipe[k];
            }
        }
    }
    return recipe;
}
function _getRecipeContent(args, host, token, result) {
    var id = args["id"];
    var savejpk = args["savejpk"];
    if (savejpk) {
        savejpk = common_1.normalizePath(savejpk);
        if (fs.existsSync(savejpk) && fs.lstatSync(savejpk).isDirectory()) {
            savejpk = path.join(savejpk, result + ".jpk");
        }
        if (!common_1.canWriteToPath(savejpk)) {
            savejpk = null;
        }
    }
    if (savejpk) {
        var reqURL = host + common_1.citizenApiPrefix + "/orgs/" + common_1.getOrgId() + "/recipes/" + id + "/content";
        request.get(reqURL)
            .set("authToken", token)
            .buffer()
            .parse(binaryParser)
            .end(function (err, res) {
            if (err) {
                common_1.printDetailedError("Could not get Jitterpak for recipe with ID " + id, err);
                process.exit(1);
            }
            else {
                var stream = fs.createWriteStream(savejpk);
                stream.write(res.body);
                stream.end();
                console.log("Jitterpak saved to %s.", savejpk);
            }
        });
    }
}
function binaryParser(res, callback) {
    res.setEncoding("binary");
    res["data"] = "";
    res.on("data", function (chunk) {
        res["data"] += chunk;
    });
    res.on("end", function () {
        callback(null, new Buffer(res["data"], "binary"));
    });
}
