"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var request = require("superagent");
var common_1 = require("../common");
function listRecipes(args) {
    common_1.authenticate(args, _listRecipes);
}
exports.listRecipes = listRecipes;
function _listRecipes(args, host, token) {
    var limit = args["limit"];
    var offset = args["page"] - 1 || 0;
    if (offset < 0) {
        offset = 0;
    }
    var page = offset * limit;
    var privat = args["private"];
    var reqURL = host + common_1.citizenApiPrefix + "/orgs/" + common_1.getOrgId() + "/recipes";
    var r = request.get(reqURL)
        .set("authToken", token);
    r.query("size=" + limit);
    r.query("offset=" + page);
    if (privat) {
        r.query("public=" + !privat);
    }
    r.end(function (err, res) {
        if (err) {
            common_1.printDetailedError("Could not list recipes", err);
            process.exit(1);
        }
        else {
            var recipes = res.body;
            recipes.sort(function (a, b) {
                if (+a.id < +b.id) {
                    return 1;
                }
                if (+a.id > +b.id) {
                    return -1;
                }
                return 0;
            });
            if (recipes.length === 0) {
                console.log("No recipes found.");
            }
            else {
                for (var _i = 0, recipes_1 = recipes; _i < recipes_1.length; _i++) {
                    var recipe = recipes_1[_i];
                    console.log((recipe.isPublic ? "*" : " ") + "[" + (recipe.id || recipe.guid) + "] " +
                        recipe.name + " by " + recipe.author.name + " (" + recipe.author.orgName + ")");
                }
            }
        }
    });
}
