"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var request = require("superagent");
var common_1 = require("../common");
function uploadRecipe(args) {
    common_1.authenticate(args, _uploadRecipe);
}
exports.uploadRecipe = uploadRecipe;
function _uploadRecipe(args, host, token) {
    var jpk = common_1.normalizePath(args["jpk"]);
    var recipe = args["recipe"];
    var pub = args["public"].toString() || "false";
    if (!fs.existsSync(jpk)) {
        common_1.printDetailedError("Jitterpak file not found.");
        process.exit(1);
    }
    if (recipe) {
        recipe = common_1.normalizePath(recipe);
        if (!fs.existsSync(recipe)) {
            common_1.printDetailedError("Recipe file not found.");
            process.exit(1);
        }
    }
    var reqURL = host + common_1.citizenApiPrefix + "/orgs/" + common_1.getOrgId() + "/recipes";
    var r = request.post(reqURL)
        .set("authToken", token)
        .field("permissions", JSON.stringify({ public: pub }))
        .attach("jitterpack", jpk);
    if (recipe) {
        r.attach("recipe", recipe);
    }
    r.type("multipart/form-data");
    r.end(function (err, res) {
        if (err) {
            common_1.printDetailedError("Could not upload recipe", err);
            process.exit(1);
        }
        else {
            var newId = res.text;
            common_1.setRecipeId(recipe, newId);
            console.log("Recipe uploaded, assigned ID " + newId + ".");
        }
    });
}
