"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var request = require("superagent");
var common_1 = require("../common");
function validateRecipe(args) {
    common_1.authenticate(args, _validateRecipe);
}
exports.validateRecipe = validateRecipe;
function _validateRecipe(args, host, token) {
    var recipeFile = common_1.normalizePath(args["recipe"]);
    if (!fs.existsSync(recipeFile)) {
        common_1.printDetailedError("Recipe file not found.");
        process.exit(1);
    }
    if (!recipeFile.endsWith(".json")) {
        common_1.printDetailedError("Recipe file must end in '.json'.");
        process.exit(1);
    }
    var recipe;
    try {
        recipe = JSON.stringify(require(recipeFile));
    }
    catch (e) {
        common_1.printDetailedError("Failed to read recipe file", e);
        process.exit(1);
    }
    var reqURL = host + common_1.citizenApiPrefix + "/validate/recipe";
    var r = request.put(reqURL)
        .set("authToken", token)
        .send(recipe);
    r.type("application/json");
    r.end(function (err, res) {
        if (err) {
            if (typeof err.response.body.message.errorMessage === "string") {
                var messArr = err.response.body.message.errorMessage.split("\n");
                if (messArr.length > 1) {
                    messArr.shift();
                }
                err.response.body.message.errorMessage = messArr.join("\n");
            }
            common_1.printDetailedError("Failed to validate recipe", err);
            process.exit(1);
        }
        else {
            console.log("Recipe is valid.");
        }
    });
}
