var del        = require('del');
var gulp       = require('gulp');
var install    = require("gulp-install");
var sequence   = require('gulp-sequence').use(gulp);
var tslint     = require('gulp-tslint');
var typescript = require('gulp-typescript');
var typings    = require('gulp-typings');

var src = ['./src/**/*.ts'];

// CLEANING

gulp.task('clean', function() {
  return del(['./dist/']);
});

gulp.task('clean_node_modules', function() {
  return del(['./node_modules/']);
});

gulp.task('clean_typings', function() {
  return del(['./typings/']);
});

gulp.task('deepclean', sequence('clean_node_modules', 'clean_typings', 'clean'));

// INSTALLING

gulp.task('install_npm', function() {
  return gulp.src('./package.json')
    .pipe(install());
});

gulp.task('install_typings', function() {
  return gulp.src('./typings.json')
    .pipe(typings());
});

gulp.task('install', sequence('install_npm', 'install_typings'));

// BUILDING

gulp.task('tslint', function() {
  return gulp.src(src)
    .pipe(tslint({
      configuration: "./tslint.json",
      fix: true,
    }))
    .pipe(tslint.report({
      summarizeFailureOutput: true,
    }));
});

gulp.task('compile', function() {
  var tsProject = typescript.createProject("./tsconfig.json");
  return tsProject
    .src()
    .pipe(tsProject())
    .pipe(gulp.dest("./dist/"));
});

gulp.task('build', sequence('tslint', 'compile'));

gulp.task('rebuild', sequence('clean', 'build'));

gulp.task('default', sequence('build'));
